/*
 * Params:
 * id: file id (required)
 * Output:
 * result: updated file
 */
lm.component('lmDialogFileEdit', {
	templateUrl: 'comp/dialog/lmDialogFileEdit.' + lmCacheTag + 'html',
	bindings: { lmParams: '<', lmDismiss: '&', lmDone: '&' },
	controller: function($element, $http, serviceLimboMedia, serviceNotification) {
		var ctrl = this;

		ctrl.file = null;
		
		ctrl.vTranscodings = [];
		ctrl.aTranscodings = [];
		
		/* Use dialog itself as backdrop for popper. */
		ctrl.elementOutside = $element.get(0);
		
		ctrl.$onInit = function() {
			/* load file details */
			$http.get(lmBase.url + 'f/file/' + ctrl.lmParams.id).then(
				function success(resp) {
					ctrl.file = resp.data;
					if('VIDEO' == ctrl.file.type) {
						for(x in lmBase.videoFormats) {
							var vt = lmBase.videoFormats[x];
							var already = false;
							for(y in ctrl.file.formats) {
								var form = ctrl.file.formats[y];
								if(!form.original && vt.standard == form.standard && vt.layout == form.layout) already = true;
							}
							if(!already) ctrl.vTranscodings.push(vt);
						}
					}
					if('AUDIO' == ctrl.file.type) {
						for(x in lmBase.audioFormats) {
							var vt = lmBase.audioFormats[x];
							for(y in ctrl.file.formats) {
								var form = ctrl.file.formats[y];
								var already = false;
								if(vt.standard == form.standard) {
									already = true;
								}
							}
							if(!already) ctrl.aTranscodings.push(vt);
						}
					}
				},
				serviceLimboMedia.handleHttpErrorNew
			);			
		};
		
		ctrl.save = function() {
			var req = {name: ctrl.file.name};
			$http.post(lmBase.url + 'f/file/' + ctrl.file.id,req).then(
				function success(resp) {
					ctrl.lmDone({result: resp.data});
				},
				serviceLimboMedia.handleHttpErrorNew
			);
		};

		ctrl.doReindex = function() {
			$http.post(lmBase.url + 'f/file/' + ctrl.file.id + '/reindex').then(
				function success(resp) {
					ctrl.lmDone();
				},
				serviceLimboMedia.handleHttpErrorNew
			);		
		};
		
		ctrl.doVTranscode = function(vTrans) {
			$http.post(lmBase.url + 'f/video/' + ctrl.file.id + '/encode',vTrans).then(
				function success(resp) {
					serviceNotification.ok('MSG_JOB_STARTED');
				},
				serviceLimboMedia.handleHttpErrorNew
			);
		};

		ctrl.doATranscode = function(aTrans) {
			$http.post(lmBase.url + 'f/audio/' + ctrl.file.id + '/encode',aTrans).then(
				function success(resp) {
					serviceNotification.ok('MSG_JOB_STARTED');
				},
				serviceLimboMedia.handleHttpErrorNew
			);
		};		
		
	}
});
