lm.component('lmRrdGraph', {
  templateUrl: 'comp/misc/lmRrdGraph.' + lmCacheTag + 'html',
  bindings: {
	  lmModel: '<'
  },
  controller: function($scope, $element, $http, $translate, serviceLimboMedia, serviceNotification, serviceDeps) {
	  var ctrl = this;
	  
	  ctrl.el = $element[0].getElementsByClassName('rrdgraph')[0];
	  ctrl.initialized = false;
	  
	  ctrl.rrdSelected = null;
	  
	  ctrl.$onChanges = function(cobj) {
		  ctrl.init();
	  };	  
	  
	  ctrl.$postLink = function() {
		  serviceDeps.load("plot").then(function() {
			  ctrl.initialized = true;
			  ctrl.init();
		  });
	  };
	  
	  ctrl.init = function() {
		  if(!ctrl.initialized || !ctrl.lmModel) return;
		  
		  if(ctrl.lmModel.rrdFile) {
			  ctrl.drawFile();
		  }
		  else {
			  var earl = lmBase.url + 'rrd/file/' + ctrl.lmModel.id; 
			  FetchBinaryURLAsync(earl,function(bf, valueFile) {$scope.$apply(ctrl.onRrdFileLoaded(bf,valueFile));},ctrl.lmModel);
		  }
	  };
	  
	  ctrl.onRrdFileLoaded = function(bf,valueFile) {
			if (bf.getLength()<1) {
				// load error or file empty
	    		return;
	  		}
	  		
			valueFile.rrds = [];
			valueFile.dss = [];
			
			try {
				valueFile.rrdFile = new RRDFile(bf,new Object());
				
				var nrRRAs=valueFile.rrdFile.getNrRRAs();
				for (var i=0; i<nrRRAs; i++) {
					var rra=valueFile.rrdFile.getRRAInfo(i);
					
					var obj = new Object();
					obj.id = i;
					obj.step = rra.getStep();
					obj.rows = rra.getNrRows();
				    obj.period = obj.step*obj.rows; 
				    obj.name = rfs_format_time(obj.step)+" ("+rfs_format_time(obj.period)+" total)";
				    valueFile.rrds.push(obj);
				}
				
				var nrDSs=valueFile.rrdFile.getNrDSs();
				for (var i=0; i<nrDSs; i++) {
					var ds=valueFile.rrdFile.getDS(i);
					
					var obj = new Object();
					obj.id = i;
					obj.name = ds.getName();
					obj.type = ds.getType();
					valueFile.dss.push(obj);
				}
				ctrl.drawFile();
			} catch(err) {
				serviceNotification.error('MSG_RRD');
			}
		};
		
		ctrl.drawFile = function() {
			if(!ctrl.lmModel || !ctrl.lmModel.rrds || ctrl.lmModel.rrds.length == 0) {
				return;
			}
			
			if(!ctrl.rrdSelected) ctrl.rrdSelected = ctrl.lmModel.rrds[0];
		
			var ds_positive_stack_list=[];
			var ds_negative_stack_list=[];
			var ds_single_list=[];
			
			for(x in ctrl.lmModel.dss) {
				ds_single_list.push(ctrl.lmModel.dss[x].name);
			}
			
			// then extract RRA data about those DSs
  			var flot_obj=rrdRRAStackFlotObj(ctrl.lmModel.rrdFile,ctrl.rrdSelected.id,ds_positive_stack_list,ds_negative_stack_list,ds_single_list,0*3600);			
			
			var graph_options = ctrl.graphOptions(ctrl.lmModel);
						
			graph_options.xaxis.min=flot_obj.min;
			graph_options.xaxis.max=flot_obj.max;
    	
			var graph = $.plot(ctrl.el, flot_obj.data, graph_options);
		};
		
		ctrl.graphOptions = function(valueFile) {
			var result = {
				legend: {show:true, position:"nw",noColumns:3},
				lines: {show:true},
				xaxis: { mode: "time" },
				yaxis: { autoscaleMargin: 0.20},
				selection: { mode: "x" },
				tooltip: true,
				tooltipOpts: { content: "<h4>%s</h4> Value: %y.3" },
				grid: { hoverable: true },
			};
			
			if(valueFile.plugin == "uptime")				result.yaxis.tickFormatter = ctrl.tfUptime;
			else if(valueFile.plugin == "cpufreq")			result.yaxis.tickFormatter = ctrl.tfCpuFreq;
			else if(valueFile.plugin == "df")				result.yaxis.tickFormatter = ctrl.tfDf;
			else if(valueFile.name.indexOf("octets") != -1)	result.yaxis.tickFormatter = ctrl.tfIfOctets;
			
			return result;
		};
		
		ctrl.tfUptime = function(val, axis) {
			if(val > 86400) 		return (val / 86400).toFixed(axis.tickDecimals) + " days";
			else if (val > 3600)	return (val / 3600).toFixed(axis.tickDecimals) + " hrs";
			else if (val > 60)		return (val / 60).toFixed(axis.tickDecimals) + " min";
			else					return val.toFixed(axis.tickDecimals) + " secs";
		};
		ctrl.tfDf = function(val, axis) {
			if (val > 10000000000)		return (val / 1000000000).toFixed(axis.tickDecimals) + " GB";
			else if (val > 10000000)	return (val / 1000000).toFixed(axis.tickDecimals) + " MB";
			else if (val > 1000)		return (val / 1000).toFixed(axis.tickDecimals) + " kB";
			else						return val.toFixed(axis.tickDecimals) + " B";
		};
		ctrl.tfIfOctets = function(val, axis) {
			if (val > 10000000)			return (val / 1000000).toFixed(axis.tickDecimals) + " MB";
			else if (val > 1000)		return (val / 1000).toFixed(axis.tickDecimals) + " kB";
			else						return val.toFixed(axis.tickDecimals) + " B";
		};
		ctrl.tfCpuFreq = function(val, axis) {
			if (val > 1000000)			return (val / 1000000).toFixed(axis.tickDecimals) + " mhz";
			else if (val > 1000)		return (val / 1000).toFixed(axis.tickDecimals) + " khz";
			else						return val.toFixed(axis.tickDecimals) + " mhz";
		};		
	  
  }
});
