/* ===================================== */
/* = Global vars and utility functions = */
/* ===================================== */

var lmBase = new Object();
lmBase.urlFull = document.getElementById("pixel").src.replace("img/pixel.png","");
lmBase.urlSock = 'ws' + lmBase.urlFull.substr(4);
lmBase.url = 'api/';

lmBase.reExt = new RegExp('\\..{1,5}$');
lmBase.authorities = ['ROLE_EDIT_USER_DETAILS','ROLE_WRITE','ROLE_ACCESS_FILESYSTEM','ROLE_NETWORK','ROLE_ADMINISTRATION'];

lmBase.charsets = ['UTF-8','ISO-8859-1','US-ASCII'];

lmBase.filetypefontmapping = {
	'VIDEO': 'icon-file-video',
	'AUDIO': 'icon-file-audio',
	'IMAGE': 'icon-file-image'
};

lmBase.videoFormats = [
	{standard: 'WEBM',layout: 'P360',original: false,transcoding: true,mime: 'video/webm'},
	{standard: 'WEBM',layout: 'P720',original: false,transcoding: true,mime: 'video/webm'},
	{standard: 'WEBM',layout: 'P1080',original: false,transcoding: true,mime: 'video/webm'},
	{standard: 'MP4',layout: 'P360',original: false,transcoding: true,mime: 'video/mp4'},
	{standard: 'MP4',layout: 'P720',original: false,transcoding: true,mime: 'video/mp4'},
	{standard: 'MP4',layout: 'P1080',original: false,transcoding: true,mime: 'video/mp4'}
];

lmBase.audioFormats = [
    {standard: 'WEBM_VORBIS'},
    {standard: 'MP3'}
];

lmBase.textExtensions = ['.c','.cfg','.config','.conf','.cpp','.css','.csv','.h','.html','.ini','.java','.js','.json','.log','.php','.pom','.properties','.py','.sh','.txt','.xml','.nfo','.md','.ts','.yaml'];

lmBase.niceSize = function (bytes) {
	if (bytes == null) return '';
    if (bytes == 0) return 'n/a';
    var sizes = ['b', 'kb', 'mb', 'gb', 'tb', 'pb', 'eb', 'zb', 'yb'],
    i = parseInt(Math.floor(Math.log(bytes) / Math.log(1024)));
    return Math.round(bytes / Math.pow(1024, i), 2) + ' ' + sizes[i];
};

lmBase.secondsToString = function(valueSeconds) {
	if(isFinite(String(valueSeconds))) {
		var dur = moment.duration(valueSeconds * 1000);
		var ss = dur.seconds();
		if(ss < 10) ss = '0' + ss;
		var mm = dur.minutes();
		if(mm < 10) mm = '0' + mm;
		var hh = dur.hours();
		if(hh < 10) hh = '0' + hh;
		return hh + ':' + mm + ':' + ss;
	}
	else return 'unknown';
};

lmBase.timestampToDate = function(valueTimestamp) {
	var x = moment(valueTimestamp);
	if(x.isValid()) {
		return x.format("YYYY-MM-DD");
	}
	else {
		return null;
	}
};

lmBase.timestampToDateTime = function(valueTimestamp) {
	var x = moment(valueTimestamp);
	if(x.isValid()) {
		return x.format("YYYY-MM-DD HH:mm:ss");
	}
	else {
		return null;
	}
};

lmBase.getOffset = function(el) {
    var _x = 0;
    var _y = 0;
    var _w = el.offsetWidth;
    while( el && !isNaN( el.offsetLeft ) && !isNaN( el.offsetTop ) ) {
        _x += el.offsetLeft - el.scrollLeft;
        _y += el.offsetTop - el.scrollTop;
        el = el.offsetParent;
    }
    return { top: _y, left: _x, width: _w};
};

lmBase.cutToAscii = function(val) {
	return val.replace(/[^\x00-\x7F]/g, "");
};

lmBase.cutToLatin1 = function(val) {
	return val.replace(/[^\x00-\xFF]/g, "");
};

lmBase.mouseInElement = function(evt) {
	return lmBase.mouseInDiv(evt.currentTarget,evt);
}

lmBase.mouseInDiv = function(el,evt) {
	var xmouse = evt.clientX;
	var divCords = lmBase.getOffset(el);
	var res = (xmouse - divCords.left) / divCords.width;
	return res; 
};

lmBase.arrayToCSV = function(values) {
	var csvstring = '';
		for(x in values) {
			var val = values[x];
			if(csvstring != '') csvstring += ',';
			csvstring += val.id;
		}
	return csvstring;
};

lmBase.arrayToIdArray = function(values) {
	var result = [];
	for(x in values) {
		var val = values[x];
		result.push(val.id);
	}
	return result;
};

lmBase.arrayGetNext = function(valArray, valCurrent) {
	var posNext = valArray.indexOf(valCurrent) + 1;
	if(posNext >= valArray.length) {
		posNext = 0;
	}
	return valArray[posNext];
};

lmBase.arrayGetByIdOrFirst = function(valArray, valId) {
	for(x in valArray) {
		if(valArray[x].id == valId) {
			return valArray[x];
		}
	}
	return valArray[0];
};


lmBase.stringArrayToCSV = function(values) {
	var csvstring = '';
		for(x in values) {
			var val = values[x];
			if(csvstring != '') csvstring += ',';
			csvstring += val;
		}
	
	return csvstring;
};

lmBase.multiSelectionInit = function(targetArray, items, selected) {
	targetArray.splice(0,targetArray.length);
	for(x in items) {
		var ok = new Object();
		ok.selected = false;
		if(selected != null) {
			for(y in selected) {
				if(selected[y] == items[x]) {
					ok.selected = true;
				}
			};
		};
		ok.item = items[x];
		targetArray.push(ok);
	}
};

lmBase.multiSelectionGetSelected = function(valueArray) {
	var result = new Array();
	for(x in valueArray) {
		var item = valueArray[x];
		if(item.selected) {
			result.push(item.item);
		}
	}
	return result;
};

lmBase.pimpLmFile = function(valueItem) {
	valueItem.client = new Object();
	valueItem.client.select = false;
	valueItem.client.downurl = lmBase.url + 'f/stream/' + valueItem.id + '/' + encodeURIComponent(valueItem.name);
};

/* Sorting */
lmBase.prioVideoFormat = function(vf) {
	var result = 0;
	
	if("P360" == vf.layout) result += 256;
	if("P720" == vf.layout) result += 128;
	if("P1080" == vf.layout) result += 64;
	if("P2160" == vf.layout) result += 32;
	if("WEBM" == vf.standard) result += 8;
	if("MP4" == vf.standard) result += 4;
	
	// prefer already encoded
	if(!vf.transcoding) result += 1024;

	// original is always last.
	if(vf.original) result -= 2048;

	return result;
}

lmBase.compareVideoFormat = function(v1, v2) {
	return lmBase.prioVideoFormat(v2) - lmBase.prioVideoFormat(v1);
};


lmBase.isFilePdf = function(valFile) {
	var str = valFile.name.toLowerCase();
	return str.endsWith('.pdf');
};

lmBase.isFileText = function(valFile) {
	if(valFile.type != 'SIMPLE') return false;
	var str = valFile.name.toLowerCase();
	for(x in lmBase.textExtensions) {
		if(str.endsWith(lmBase.textExtensions[x])) return true;
	}
	return false;
};

lmBase.defaultSettingsFiles = function(settings) {
	if(settings.view == null) settings.view = 'LIST';
	if(settings.filter == null) settings.filter = 'ALL';
	if(settings.pageSize == null) settings.pageSize = 100;

	if(settings.list == null) settings.list = new Object();
	if(settings.list.colDuration == null) settings.list.colDuration = false;
	if(settings.list.colSize == null) settings.list.colSize = true;
	if(settings.list.colTsAdd == null) settings.list.colTsAdd = false;
	if(settings.list.colTsMod == null) settings.list.colTsMod = true;
	if(settings.list.colTsMade == null) settings.list.colTsMade = false;
	if(settings.list.size == null) settings.list.size = 'MEDIUM';

	if(settings.audio == null) settings.audio = new Object();
	if(settings.audio.colAlbum == null) settings.audio.colAlbum = false;
	if(settings.audio.colGenre == null) settings.audio.colGenre = false;
	if(settings.audio.colTrack == null) settings.audio.colTrack = false;
	if(settings.audio.colDuration == null) settings.audio.colDuration = true;
	if(settings.audio.colSize == null) settings.audio.colSize = false;
	if(settings.audio.colTsAdd == null) settings.audio.colTsAdd = false;
	if(settings.audio.colTsMod == null) settings.audio.colTsMod = true;
	if(settings.audio.colTsMade == null) settings.audio.colTsMade = false;
	
	if(settings.gallery == null) settings.gallery = new Object();
	if(settings.gallery.size == null) settings.gallery.size = 'MEDIUM';
};

